@@ -13,9 +13,10 @@ class PhaseStatus(StrEnum):
 
 
 class Phase(BaseModel):
-    status: PhaseStatus
     target: Coordinates
-    start_time: datetime = Field(default_factory=datetime.now)
+    status: PhaseStatus = PhaseStatus.waiting
+    create_time: datetime = Field(default_factory=datetime.now)
+    start_time: datetime | None = None
     end_time: datetime | None
 
 
