@@ -1,5 +1,4 @@
 import uuid
-from abc import ABC, abstractmethod
 from datetime import datetime
 from enum import StrEnum
 
@@ -19,22 +18,21 @@ class RoomStatus(StrEnum):
     closed = 'closed'
 
 
-class BaseRoom(BaseModel, ABC):
+class BaseRoom(BaseModel):
     id: str = Field(alias='id_', default_factory=lambda: str(uuid.uuid4()))
     map: str = 'world'
     status: RoomStatus = RoomStatus.waiting
     create_time: datetime = Field(default_factory=datetime.now)
     start_time: datetime | None = None
-    mode: str = None
+    mode: RoomMode | None = None
 
     @validator("mode", always=True)
     def compute_mode(cls, value):
-        return cls.get_mode()
+        return cls.get_mode() or value
 
     @staticmethod
-    @abstractmethod
-    def get_mode() -> RoomMode:
-        pass
+    def get_mode() -> RoomMode | None:
+        return None
 
     class Config:
         allow_population_by_field_name = True
