@@ -11,6 +11,9 @@ class UserBase(BaseModel):
 class User(UserBase):
     id: str = Field(alias='id_', default_factory=lambda: str(uuid.uuid4()))
 
+    class Config:
+        allow_population_by_field_name = True
+
 
 class UserCreate(UserBase):
     password: str
